## Evaluator callbacks

::: ropt.evaluator.Evaluator
    options:
        heading_level: 3
::: ropt.evaluator.EvaluatorContext
    options:
        heading_level: 3
::: ropt.evaluator.EvaluatorResult
    options:
        heading_level: 3

## Optional implementations

::: ropt.evaluator.ConcurrentEvaluator
    options:
        heading_level: 3
        members:
            - __init__
            - launch
            - monitor
            - polling
::: ropt.evaluator.ConcurrentTask
    options:
        heading_level: 3
